@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012, 2013, 2014 Red Hat, Inc.
+ * Copyright © 2012, 2013, 2014, 2015 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -43,12 +43,7 @@
 #include "photos-media-server-item.h"
 #include "photos-query.h"
 #include "photos-source.h"
-#include "photos-tracker-collections-controller.h"
-#include "photos-tracker-controller.h"
-#include "photos-tracker-favorites-controller.h"
-#include "photos-tracker-overview-controller.h"
 #include "photos-tracker-queue.h"
-#include "photos-tracker-search-controller.h"
 #include "photos-utils.h"
 
 
@@ -535,11 +530,6 @@ photos_utils_ensure_builtins (void)
       g_type_ensure (PHOTOS_TYPE_LOCAL_ITEM);
       g_type_ensure (PHOTOS_TYPE_MEDIA_SERVER_ITEM);
 
-      g_type_ensure (PHOTOS_TYPE_TRACKER_COLLECTIONS_CONTROLLER);
-      g_type_ensure (PHOTOS_TYPE_TRACKER_FAVORITES_CONTROLLER);
-      g_type_ensure (PHOTOS_TYPE_TRACKER_OVERVIEW_CONTROLLER);
-      g_type_ensure (PHOTOS_TYPE_TRACKER_SEARCH_CONTROLLER);
-
       g_once_init_leave (&once_init_value, 1);
     }
 }
@@ -557,9 +547,6 @@ photos_utils_ensure_extension_points (void)
       extension_point = g_io_extension_point_register (PHOTOS_BASE_ITEM_EXTENSION_POINT_NAME);
       g_io_extension_point_set_required_type (extension_point, PHOTOS_TYPE_BASE_ITEM);
 
-      extension_point = g_io_extension_point_register (PHOTOS_TRACKER_CONTROLLER_EXTENSION_POINT_NAME);
-      g_io_extension_point_set_required_type (extension_point, PHOTOS_TYPE_TRACKER_CONTROLLER);
-
       g_once_init_leave (&once_init_value, 1);
     }
 }
@@ -632,6 +619,41 @@ photos_utils_flash_on_quark (void)
 }
 
 
+gchar *
+photos_utils_get_extension_from_mime_type (const gchar *mime_type)
+{
+  GSList *formats;
+  GSList *l;
+  gchar *ret_val = NULL;
+
+  formats = gdk_pixbuf_get_formats ();
+
+  for (l = formats; l != NULL; l = l->next)
+    {
+      GdkPixbufFormat *format = (GdkPixbufFormat*) l->data;
+      gchar **supported_mime_types;
+      guint i;
+
+      supported_mime_types = gdk_pixbuf_format_get_mime_types (format);
+      for (i = 0; supported_mime_types[i] != NULL; i++)
+        {
+          if (g_strcmp0 (mime_type, supported_mime_types[i]) == 0)
+            {
+              ret_val = photos_utils_get_pixbuf_common_suffix (format);
+              break;
+            }
+        }
+
+      g_strfreev (supported_mime_types);
+      if (ret_val != NULL)
+        break;
+    }
+
+  g_slist_free (formats);
+  return ret_val;
+}
+
+
 gint
 photos_utils_get_icon_size (void)
 {
